@@ -72,12 +72,12 @@ impl ColorMode {
 
     /// Set color depth to 8-bit palette and set the colors
     pub fn set_palette(&mut self, palette: &[RGBA]) -> Result<(), Error> {
+        self.palette_clear();
         for &c in palette {
             self.palette_add(c)?;
         }
         self.colortype = ColorType::PALETTE;
         self.set_bitdepth(8);
-        self.palette_clear();
         Ok(())
     }
 
@@ -1059,6 +1059,12 @@ impl<'a> ChunkRef<'a> {
         &self.data[8..8 + len]
     }
 
+    #[inline]
+    pub fn crc(&self) -> u32 {
+        let length = self.len();
+        crc32fast::hash(&self.data[4..length + 8])
+    }
+
     #[cfg(not(fuzzing))]
     pub fn check_crc(&self) -> bool {
         let length = self.len();
@@ -1068,12 +1074,6 @@ impl<'a> ChunkRef<'a> {
         crc == checksum
     }
 
-    #[inline]
-    pub fn crc(&self) -> u32 {
-        let length = self.len();
-        lodepng_crc32(&self.data[4..length + 8])
-    }
-
     #[cfg(fuzzing)]
     /// Disable crc32 checks so that random data from fuzzer gets actually parsed
     #[inline(always)]
